==> qcad-3.32.4.0-2-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Вертикальный/горизонтальный</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Назад</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Сетка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Конец</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>На объекте</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Перпендикуляр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Тангенциальный</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Центр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Средний</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Пересечение</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Расстояние</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Неверный</translation>
    </message>
</context>
</TS>

==> qcad-3.32.6.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Вертикальный/горизонтальный</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Сетка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Конец</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>На объекте</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Перпендикуляр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Тангенциальный</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Центр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Средний</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Пересечение</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Расстояние</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Неверный</translation>
    </message>
</context>
</TS>
